@@ -3,7 +3,6 @@ Entry point for the CLI
 """
 import sys
 import json
-import argparse
 
 from sfb.entrypoint import EntryPoint
 
@@ -14,4 +13,4 @@ def cli():
         results[response['Status']].append(response['Result'])
 
     print(json.dumps(results, indent=2))
-    sys.exit(0)
+    exit(0)
